# 2022-03-04 - ERC4626 Linear Pool V1

> ⚠️ **DEPRECATED: do not use** ⚠️
>
> This factory and associated Pools have been deprecated due to changes to the EIP-4626 standard. It was superseded by this [updated version (also now deprecated)](../20220404-erc4626-linear-pool-v2).

Preliminary deployment of the `ERC4626LinearPoolFactory`, for Linear Pools with a ERC4626 yield-bearing token.

## Useful Files

- [Polygon mainnet addresses](./output/polygon.json)
- [`ERC4626LinearPoolFactory` artifact](./artifact/ERC4626LinearPoolFactory.json)
